@@ -53,6 +53,7 @@ int snprintf(char *, size_t, const char *, ...);
 #ifndef HAVE_SNPRINTF
 int snprintf(char *str, size_t size, const char *format, ...)
 {
+	int slen;
         va_list ap;
 	char *ptr;
 
@@ -68,8 +69,9 @@ int snprintf(char *str, size_t size, const char *format, ...)
 		free(ptr);
 		return -1;
 	}
+	slen = strlen(ptr);
 	free(ptr);
-	return strlen(ptr);
+	return slen;
 }
 #endif
 
