@@ -263,6 +263,14 @@ int registerconnection()
 	}
 	if(mystate->current_server->registered == OER_REGISTERCONNECTION_STATUS_BEGIN) {
 		oer_debug(OER_DEBUG_INFO, "registerconnection->registering on the server\n");
+		if(strlen(mystate->current_server->password)) {
+			snprintf(stringbuffer, WRITE_BUFFER_LENGTH, "PASS %s\n", mystate->current_server->password);
+			oer_debug(OER_DEBUG_INFO, "registerconnection->%s", stringbuffer);
+			if(write(mystate->sockfd, stringbuffer, strlen(stringbuffer)) < 0) {
+				oer_debug(OER_DEBUG_ERROR, "registerconnection->write failed: %s\n", strerror(errno));
+				return OER_REGISTERCONNECTION_ERR_WRITE;
+			}
+		}
 		snprintf(stringbuffer, WRITE_BUFFER_LENGTH, "NICK %s\n", (mystate->use_alt_nick) ? mystate->altnick : mystate->nick);
 		oer_debug(OER_DEBUG_INFO, "registerconnection->%s", stringbuffer);
 		if(write(mystate->sockfd, stringbuffer, strlen(stringbuffer)) < 0) {
@@ -506,32 +514,27 @@ int processtimeds()
 			actions++;
 			mystate->current_server->lastping = mystate->now;
 		}
-		/* only 1 timed, special case */
-		if(tim->prev == NULL && tim->next == NULL) {
-			free(tim->irc_command);
-			free(tim->optstring1);
-			free(tim->optstring2);
-			free(tim->optstring3);
-			free(tim);
-			mystate->timeds = NULL;
-			return OER_PROCESSTIMEDS_EVERYTHING_OK;
-		}
-		/* the normal case, >1 timeds */
+		/* adjust lists */
 		if(tim->prev == NULL) {
-			/* 1st timed */
+			/* first timed in list */
 			mystate->timeds = tim->next;
-			tim->next->prev = NULL;
-		} else {
-			/* in between > 1 timeds */
-			if(tim->next == NULL) {
-				/* last timed */
-				tim->prev->next = NULL;
-			} else {
-				/* between 1 or more timeds */
-				tim->prev->next = tim->next;
-				tim->next->prev = tim->prev;
+			/* ... check if also last */
+			if(tim->next != NULL) {
+				tim->next->prev = NULL;
 			}
 		}
+		if(tim->next == NULL) {
+			/* last timed in list */
+			/* ... check also if the only one */
+			if(tim->prev != NULL) {
+				tim->prev->next = NULL;
+			}
+		}
+		if(tim->prev != NULL && tim->next != NULL) {
+			/* between 2 or more timed */
+			tim->prev->next = tim->next;
+			tim->next->prev = tim->prev;
+		}
 		free(tim->irc_command);
 		free(tim->optstring1);
 		free(tim->optstring2);
